@@ -3,7 +3,6 @@ import configparser
 import os
 import pathlib
 import logging
-import traceback
 import functools
 from .uwException import * 
 
@@ -205,6 +204,9 @@ class cmnConfig(cmnConfigBase):
         self.LogLevel:int = logging.DEBUG
         """ ログレベル """
 
+        self.ErrorLogFileName = 'error.log'
+        """ エラーログファイル名 """
+        
         self.ConnectionString = self.settingValueStruct.ConnectionString()
         """ 接続文字列 """
 
@@ -269,10 +271,25 @@ class cmnConfig(cmnConfigBase):
             try:
                 raise iniFilePathError
             except iniFilePathError as e:
-                print(e)
-                with open("log/error.log", 'a') as f:
-                    traceback.print_exc(file=f)
-                    sys.exit()
+                
+                # エラー内容
+                errorText = 'iniFilePath={}'.format(iniFilePath)
+                
+                # エラーログ出力
+                writeErrorLog(self.getErrorLogFilaPath(), errorText)
+                
+                # 処理終了
+                sys.exit()
+                
+                # エラーログ出力先が無ければ作成
+                #if not os.path.exists(self.ErrorLogFilePath):
+                #    os.mkdir(self.ErrorLogFilePath)
+                
+                # エラーログ出力    
+                #with open(self.ErrorLogFilePath, 'a') as f:
+                #    traceback.print_exc(file=f)
+                #    f.write('iniFilePath={}'.format(iniFilePath))
+                #    sys.exit()
 
         # iniファイル読込
         config_ini.read(iniFilePath, encoding='utf-8')
@@ -349,4 +366,12 @@ class cmnConfig(cmnConfigBase):
         self.setConfigValue('ConnectionString.Port', self.config_ini,'CONNECTION_STRING','PORT', str)
         # データベース名
         self.setConfigValue('ConnectionString.DatabaseName', self.config_ini,'CONNECTION_STRING','DATABASE_NAME', str)
-    
\ No newline at end of file
+    
+    def getErrorLogFilaPath(self):
+        
+        """
+        エラーログ出力先パスを取得する
+        """
+        
+        # エラーログ出力先
+        return os.path.join(self.LogFolderName, self.ErrorLogFileName)
\ No newline at end of file
