@@ -1,3 +1,4 @@
+from codecs import register_error
 import inspect
 import pandas as pd
 import copy
@@ -57,7 +58,19 @@ class recset(Generic[T]):
 
         cacheAndDataBase = 1
         """ キャッシュとDBの両方検索 """
+    
+    class upsertResult():
         
+        """
+        upsert処理結果クラス
+        """
+        
+        result = en.resultRegister.success
+        """ 処理結果 """
+
+        exceptInfo = None
+        """ 例外情報 """
+    
     def __init__(self, t, __da:uwDataAccess = None, __where = None) -> None:
         
         """
@@ -844,7 +857,7 @@ class recset(Generic[T]):
 
         return self.update(True)
     
-    def update(self, upsert = False) -> en.resultRegister:
+    def update(self, upsert = False) -> upsertResult:
         
         """
         データ更新(通常用)
@@ -855,6 +868,9 @@ class recset(Generic[T]):
             recset側でDBとの制約を解決していればupsertよりこちらのほうが速度は上
         """
         
+        # 処理結果クラスインスタンス
+        upResult = self.upsertResult()
+        
         try:
             
             # セッションチェック
@@ -877,7 +893,7 @@ class recset(Generic[T]):
                 self.__session.commit()
 
             # 処理結果セット
-            result = en.resultRegister.success
+            upResult.result = en.resultRegister.success
             
         except SQLAlchemyError as e:
             
@@ -885,11 +901,12 @@ class recset(Generic[T]):
             Logger.logging.error(e)
 
             # 処理結果セット
-            result = en.resultRegister.failure
-
+            upResult.result = en.resultRegister.failure
+            upResult.exceptInfo = e
+            
             # Rollback
             if self.__da.autoCommit:
                 self.__session.rollback()
-        
+            
         # 処理結果を返す
-        return result
\ No newline at end of file
+        return upResult
\ No newline at end of file
